#!/usr/bin/env python
# -*- coding: utf-8 -*-
from django.db import models
from django.utils.translation import ugettext_lazy as _

class Country(models.Model):
    """
    International Organization for Standardization (ISO) 3166-1 Country list
    
     * ``iso`` = ISO 3166-1 alpha-2
     * ``name`` = Official country names used by the ISO 3166/MA in capital letters
     * ``printable_name`` = Printable country names for in-text use
     * ``iso3`` = ISO 3166-1 alpha-3
     * ``numcode`` = ISO 3166-1 numeric
    
    Note::
        This model is fixed to the database table 'country' to be more general.
        Change ``db_table`` if this cause conflicts with your database layout.
        Or comment out the line for default django behaviour.
    
    """
    iso = models.CharField(_('ISO alpha-2'), max_length=2, primary_key=True)
    name = models.CharField(_('Official name (CAPS)'), max_length=128)
    printable_name = models.CharField(_('Country name'), max_length=128)
    iso3 = models.CharField(_('ISO alpha-3'), max_length=3, null=True)
    numcode = models.PositiveSmallIntegerField(_('ISO numeric'), null=True)
    
    class Meta:
        db_table = 'country'
        verbose_name = _('Country')
        verbose_name_plural = _('Countries')
        ordering = ('name',)
        
    class Admin:
        list_display = ('printable_name', 'iso',)
        
    def __unicode__(self):
        return self.localized_name()
    
    def localized_name(self):
        from django.utils.translation import ugettext as _
        return _(self.printable_name)


class UsState(models.Model):
    """
    United States Postal Service (USPS) State Abbreviations
    
    Note::
        This model is fixed to the database table 'usstate' to be more general.
        Change ``db_table`` if this cause conflicts with your database layout.
        Or comment out the line for default django behaviour.
    
    """
    id = models.AutoField(primary_key=True)
    name = models.CharField(_('State name'), max_length=50, null=False)
    abbrev = models.CharField(_('Abbreviation'), max_length=2, null=False)

    class Meta:
        db_table = 'usstate'
        verbose_name = _('US State')
        verbose_name_plural = _('US States')
        ordering = ('name',)

    class Admin:
        list_display = ('name', 'abbrev',)

    def __unicode__(self):
        return self.name



from django.core.management.base import NoArgsCommand


class Command(NoArgsCommand):
        help = "Exports a gettext file to translate the country names (only translation without header)"
        
        def handle_noargs(self, **options):
            from django.utils.encoding import smart_str
            from ...models import Country
            for country in Country.objects.all():
                print '# country', smart_str(country.iso)
                print 'msgid "%s"' % smart_str(country.printable_name.replace('"', '\\"'))
                print 'msgstr ""'
                print ''



# encoding: utf-8
import datetime
from south.db import db
from south.v2 import SchemaMigration
from django.db import models

class Migration(SchemaMigration):

    def forwards(self, orm):
        
        # Adding model 'Country'
        db.create_table('country', (
            ('iso', self.gf('django.db.models.fields.CharField')(max_length=2, primary_key=True)),
            ('name', self.gf('django.db.models.fields.CharField')(max_length=128)),
            ('printable_name', self.gf('django.db.models.fields.CharField')(max_length=128)),
            ('iso3', self.gf('django.db.models.fields.CharField')(max_length=3, null=True)),
            ('numcode', self.gf('django.db.models.fields.PositiveSmallIntegerField')(null=True)),
        ))
        db.send_create_signal('countries', ['Country'])

        # Adding model 'UsState'
        db.create_table('usstate', (
            ('id', self.gf('django.db.models.fields.AutoField')(primary_key=True)),
            ('name', self.gf('django.db.models.fields.CharField')(max_length=50)),
            ('abbrev', self.gf('django.db.models.fields.CharField')(max_length=2)),
        ))
        db.send_create_signal('countries', ['UsState'])


    def backwards(self, orm):
        
        # Deleting model 'Country'
        db.delete_table('country')

        # Deleting model 'UsState'
        db.delete_table('usstate')


    models = {
        'countries.country': {
            'Meta': {'ordering': "('name',)", 'object_name': 'Country', 'db_table': "'country'"},
            'iso': ('django.db.models.fields.CharField', [], {'max_length': '2', 'primary_key': 'True'}),
            'iso3': ('django.db.models.fields.CharField', [], {'max_length': '3', 'null': 'True'}),
            'name': ('django.db.models.fields.CharField', [], {'max_length': '128'}),
            'numcode': ('django.db.models.fields.PositiveSmallIntegerField', [], {'null': 'True'}),
            'printable_name': ('django.db.models.fields.CharField', [], {'max_length': '128'})
        },
        'countries.usstate': {
            'Meta': {'ordering': "('name',)", 'object_name': 'UsState', 'db_table': "'usstate'"},
            'abbrev': ('django.db.models.fields.CharField', [], {'max_length': '2'}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'name': ('django.db.models.fields.CharField', [], {'max_length': '50'})
        }
    }

    complete_apps = ['countries']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
from django import template
from django.template.defaultfilters import stringfilter

register = template.Library()

def iso_flag(iso, flag_path=u''):
	"""
	Returns a full path to the ISO 3166-1 alpha-2 country code flag image.
	
	Example usage::
		
		{{ user_profile.country.iso|iso_flag }}
		
		{{ user_profile.country.iso|iso_flag:"appmedia/flags/%s.png" }}
	
	"""
	from countries.utils.isoflag import iso_flag
	return iso_flag(iso, flag_path)
iso_flag = stringfilter(iso_flag)

# Syntax: register.filter(name of filter, callback)
register.filter('iso_flag', iso_flag)



#!/usr/bin/env python
# -*- coding: utf-8 -*-

from django.conf import settings


def iso_flag(iso, flag_path=u''):
	"""
	Returns a full path to the ISO 3166-1 alpha-2 country code flag image.
	
	``flag_path`` is given in the form
	``'<path relative to media root>/%s.gif'``
	and is appended to ``settings.MEDIA_URL`` 
	
	if a valid flag_path is not given trys to use 
	``settings.COUNTRIES_FLAG_PATH``
	defaults to ``'flags/%s.gif'``
	
	"""
	if not settings.MEDIA_URL:
		return u''
	deafult = u'-'
	if not iso:
		iso = deafult
	else:
		iso = iso.lower().strip()
	try:
		flag_name = flag_path % iso
	except (ValueError, TypeError):
		flag_path = getattr(settings, 'COUNTRIES_FLAG_PATH', u'flags/%s.gif')
		try:
			flag_name = flag_path % iso
		except (ValueError, TypeError):
			return u''
	return u''.join((settings.MEDIA_URL, flag_name))


from setuptools import setup, find_packages

setup(
    name = "countries",
    version = "0.1.1-2",
    description = 'Provides models for a "complete" list of countries',
    author = 'David Danier',
    author_email = 'david.danier@team23.de',
    url = 'https://github.com/ddanier/django_countries',
    long_description=open('README.rst', 'r').read(),
    packages = [
        'countries',
        'countries.management',
        'countries.management.commands',
        'countries.templatetags',
        'countries.utils',
        'countries.migrations',
    ],
    package_data = {
        'countries': ['fixtures/*', 'locale/*/LC_MESSAGES/*'],
    },
    install_requires = [
        'Django >=1.2',
    ],
    classifiers=[
        'Development Status :: 5 - Production/Stable',
        'Environment :: Web Environment',
        'Framework :: Django',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: BSD License',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
        'Topic :: Utilities'
    ],
)

